@@ -210,11 +210,9 @@ class ApiDoc:
                     return ParamsErrorResponse(message = f"只允许{','.join([str(i) for i in method])}请求", code = 40003)
 
                 for i in params:
-                    if i.get('name') in list(form.keys()) and i.get('require'):
+                    if i.get('require'):
                         if form.get(i.get('name')) == '' or form.get(i.get('name')) is None:
                             return ParamsErrorResponse(message = f"{i.get('name')}不能为空")
-                if len(not_list) != 0:
-                    return ParamsErrorResponse(message = f"{','.join([str(i) for i in not_list])}" + "不能为空")
                 return f(self, request, *args, **kwargs)
 
             return wrapper
